# TigerSyn
### As python package
**Download**
```
pip install tigersyn
```
**Usage**
```python
import tigersyn
tigersyn.run('s', r'C:\T1w_dir') # Producing syntheseg masks
tigersyn.run('s', r'C:\T1w_dir', r'C:\output_dir') # save to output_dir
``````